@@ -11,7 +11,7 @@ from django.http import HttpResponse
 from django.shortcuts import redirect, render
 from django.urls import path, re_path, reverse
 from django.utils.translation import gettext_lazy as _
-from openwisp_users.multitenancy import MultitenantAdminMixin
+from openwisp_users.multitenancy import MultitenantAdminMixin, MultitenantOrgFilter
 from openwisp_utils.admin import TimeReadonlyAdminMixin
 
 from .api.views import HostsSet
@@ -27,9 +27,19 @@ class SubnetAdmin(MultitenantAdminMixin, TimeReadonlyAdminMixin, ModelAdmin):
     app_label = 'openwisp_ipam'
     change_form_template = 'admin/openwisp-ipam/subnet/change_form.html'
     change_list_template = 'admin/openwisp-ipam/subnet/change_list.html'
-    list_display = ('name', 'subnet', 'master_subnet', 'description')
+    list_display = [
+        'name',
+        'organization',
+        'subnet',
+        'master_subnet',
+        'created',
+        'modified',
+    ]
+    list_filter = [('organization', MultitenantOrgFilter)]
     autocomplete_fields = ['master_subnet']
     search_fields = ['subnet', 'name']
+    list_select_related = ['organization', 'master_subnet']
+    save_on_top = True
 
     def change_view(self, request, object_id, form_url='', extra_context=None):
         instance = Subnet.objects.get(pk=object_id)
@@ -41,13 +51,11 @@ class SubnetAdmin(MultitenantAdminMixin, TimeReadonlyAdminMixin, ModelAdmin):
         # Find root master_subnet for subnet tree
         instance_root = instance
         while instance_root.master_subnet:
-            instance_root = Subnet.objects.get(
-                subnet=instance_root.master_subnet.subnet
-            )
+            instance_root = instance_root.master_subnet
         # Get instances for all subnets for root master_subnet
-        instance_subnets = Subnet.objects.filter(subnet=instance_root.subnet).values(
-            "master_subnet", "pk", "name", "subnet"
-        )
+        instance_subnets = Subnet.objects.filter(
+            subnet=instance_root.subnet, organization=instance_root.organization
+        ).values('master_subnet', 'pk', 'name', 'subnet')
         # Make subnet tree
         collection_depth = 0
         subnet_tree = [instance_subnets]
@@ -55,8 +63,8 @@ class SubnetAdmin(MultitenantAdminMixin, TimeReadonlyAdminMixin, ModelAdmin):
             instance_subnets = Subnet.objects.none()
             for slave_subnet in subnet_tree[collection_depth]:
                 instance_subnets = instance_subnets | Subnet.objects.filter(
-                    master_subnet=slave_subnet["pk"]
-                ).values("master_subnet", "pk", "name", "subnet")
+                    master_subnet=slave_subnet['pk']
+                ).values('master_subnet', 'pk', 'name', 'subnet')
             subnet_tree.append(instance_subnets)
             collection_depth += 1
 
@@ -163,11 +171,13 @@ class IpAddressAdminForm(forms.ModelForm):
 class IpAddressAdmin(MultitenantAdminMixin, TimeReadonlyAdminMixin, ModelAdmin):
     form = IpAddressAdminForm
     change_form_template = 'admin/openwisp-ipam/ip_address/change_form.html'
-    list_display = ('ip_address', 'subnet', 'description')
-    list_filter = ('subnet',)
+    list_display = ['ip_address', 'subnet', 'organization', 'created', 'modified']
+    list_filter = ['subnet', ('subnet__organization', MultitenantOrgFilter)]
     search_fields = ['ip_address']
     autocomplete_fields = ['subnet']
     multitenant_parent = 'subnet'
+    list_select_related = ['subnet', 'subnet__organization']
+    save_on_top = True
 
     class Media:
         js = (
@@ -175,6 +185,11 @@ class IpAddressAdmin(MultitenantAdminMixin, TimeReadonlyAdminMixin, ModelAdmin):
             'openwisp-ipam/js/ip-request.js',
         )
 
+    def organization(self, obj):
+        return obj.subnet.organization
+
+    organization.short_description = _('organization')
+
     def get_extra_context(self):
         url = reverse('ipam:get_next_available_ip', args=['0000'])
         return {'get_next_available_ip_url': url}
@@ -195,10 +210,10 @@ class IpAddressAdmin(MultitenantAdminMixin, TimeReadonlyAdminMixin, ModelAdmin):
         if request.POST.get('_popup'):
             return HttpResponse(
                 f"""
-            <script type='text/javascript'>
-            opener.dismissAddAnotherPopup(window, '{request.POST.get('ip_address')}');
-            </script>
-            """
+<script type='text/javascript'>
+    opener.dismissAddAnotherPopup(window, '{request.POST.get('ip_address')}');
+</script>
+                """
             )
         return response
 
@@ -210,9 +225,9 @@ class IpAddressAdmin(MultitenantAdminMixin, TimeReadonlyAdminMixin, ModelAdmin):
         if request.POST.get('_popup'):
             return HttpResponse(
                 """
-               <script type='text/javascript'>
-                  opener.dismissAddAnotherPopup(window);
-               </script>
+<script type='text/javascript'>
+    opener.dismissAddAnotherPopup(window);
+</script>
              """
             )
         return response
