@@ -2,4 +2,4 @@ from django import forms
 
 
 class IpAddressImportForm(forms.Form):
-    csvfile = forms.FileField(label="CSV File")
+    csvfile = forms.FileField(label='CSV File')
