@@ -316,3 +316,22 @@ class TestAdmin(CreateModelsMixin, PostDataMixin, TestCase):
         self.assertContains(response, "11.0.0.0/24 (Child#1)")
         self.assertContains(response, "11.0.1.0/24 (Child#2)")
         self.assertContains(response, "11.0.0.0/25 (Grantchild#1)")
+
+    def test_subnet_add_rendered(self):
+        url = reverse(f'admin:{self.app_label}_subnet_add')
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 200)
+
+    def test_ipaddress_add_rendered(self):
+        url = reverse(f'admin:{self.app_label}_ipaddress_add')
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 200)
+
+    def test_change_view_master_multitenant(self):
+        master1 = self._create_subnet(subnet='10.0.0.0/16')
+        child1 = self._create_subnet(subnet='10.0.0.0/24', master_subnet=master1)
+        org2 = self._create_org(name='org2', slug='org2')
+        self._create_subnet(subnet='10.0.0.0/16', organization=org2)
+        url = reverse(f'admin:{self.app_label}_subnet_change', args=[child1.pk])
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 200)
