@@ -2,7 +2,7 @@ from openwisp_users.tests.test_admin import TestUsersAdmin
 
 
 class TestUsersIntegration(TestUsersAdmin):
-    pass
+    is_integration_test = True
 
 
 del TestUsersAdmin
